<xsl:stylesheet version="1.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<!-- features of this 'false-color proof' stylesheet:
  
  1. imports a display stylesheet for regular display of elements
  2. attached labels showing the element type of any element of interest
  3. allows extending the labeling for whichever of these the developer wants
       (e.g. the match on 'highlight' showing the @style attribute value)
  4. falls back to label any inline elements even if not otherwise matched
  
  -->
  
<xsl:import href="ExtremeXSLT/extreme-html.xsl"/>
  
<xsl:template match="*[../text()[normalize-space()]]">
  <xsl:call-template name="label-inline"/>
</xsl:template>

<xsl:template match="acronym | expansion" priority="2">
  <xsl:call-template name="label-inline">
    <xsl:with-param name="label-style" select="'background-color: lightsalmon'"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="highlight" priority="2">
  <xsl:call-template name="label-inline">
    <xsl:with-param name="label-style" select="'background-color: peachpuff'"/>
    <xsl:with-param name="label-text">
      <xsl:value-of select="local-name()"/>
      <xsl:for-each select="@style">
        <xsl:text>[@</xsl:text>
        <xsl:value-of select="local-name()"/>
        <xsl:text>='</xsl:text>
        <xsl:value-of select="."/>
        <xsl:text>']</xsl:text>
      </xsl:for-each>
    </xsl:with-param>
  </xsl:call-template>
</xsl:template>
  
<xsl:template match="affil | subaffil | aline | city | cntry | province |
                     fname | surname | suffix | jobtitle | email | web" priority="2">
  <xsl:call-template name="label-inline">
    <xsl:with-param name="label-style" select="'border: 1px dotted black; padding: 0em'"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="bib | pub" priority="2">
  <xsl:call-template name="label-inline">
    <xsl:with-param name="label-style" select="'background-color: papayawhip'"/>
  </xsl:call-template>
</xsl:template>

<xsl:template match="title | para | deflist | randlist | seqlist | lquote | note |
                     table | sgml.block | verbatim | codeblock | figure" priority="2">
  <xsl:call-template name="label-block">
    <xsl:with-param name="label-style">
      <xsl:text>padding: 0.25em; margin: 0.25em; border: </xsl:text>
      <xsl:choose>
        <xsl:when test="not(normalize-space())">2px dashed red</xsl:when>
        <xsl:otherwise>1px dotted black</xsl:otherwise>
      </xsl:choose>
    </xsl:with-param>
  </xsl:call-template>
</xsl:template>

<xsl:template match="front | body | rear |
                     section | subsec1 | subsec2 | subsec3 |
                     acknowl | bibliog | bibitem" priority="2">
  <xsl:call-template name="label-block">
    <xsl:with-param name="label-style">padding: 0.25em; margin: 0.25em; border: 1px dotted black</xsl:with-param>
  </xsl:call-template>
</xsl:template>

<!--
<!-#                      EMPHASIS TYPES                        #->
<!ENTITY % emphs          "highlight | sub | super | web | code"  >


<!-#                      PHRASE-LEVEL ELEMENTS                 #->
<!-#                      (small, floating inside text)         #->
<!ENTITY % phrase         "acronym | acronym.grp | bibref | cit |
                           fnref | ftnote | inline.graphic |
                           mml:math | sgml |  xref "              >


<!-#                      LIST TYPES                            #->
<!ENTITY % lists          "deflist | randlist | seqlist"          >


<!-#                      PARAGRAPH-LEVEL ITEMS                 #->
<!-#                      (at the same level as a paragraph)    #->
<!ENTITY % paralevel      "figure | graphic | %lists; | lquote |
                          mml:math | note | table"                >


<!-#                      PARAGRAPH CONTENT                     #->
<!-#                      (inside a paragraph)                  #->
<!ENTITY % paratext       "%emphs; | graphic | %lists; | %phrase;
                           | sgml.block | verbatim | codeblock"   >


<!-#                      TABLE ENTRY CONTENT                   #->
<!-#                      (inside an <entry>)                   #->
<!ENTITY % paracon        "#PCDATA | %emphs; | graphic |
                           %lists; | %phrase; |
                           verbatim | sgml.block"                    >


<!-#                      ELEMENTS INSIDE AN ADDRESS            #->
<!ENTITY % address.elems  "aline | city | state | province |
                           cntry | postcode | phone | fax |
                           email | web"                           >
-->  

<xsl:template name="label-inline">
  <xsl:param name="label-style" select="'background-color: orange'"/>
  <xsl:param name="label-text">
    <xsl:value-of select="local-name()"/>
  </xsl:param>
  <span style="{$label-style}">
    <xsl:text> </xsl:text>
    <span style="font-family: sans-serif;
      font-size: smaller;
      font-weight: bold;
      font-style: normal;
      color: midnightblue;
      vertical-align: super">
      <xsl:value-of select="$label-text"/>
    </span>
    <xsl:text>&#160;</xsl:text>
    <xsl:apply-imports/>
  </span>
</xsl:template>

<xsl:template name="label-block">
  <xsl:param name="label-style" select="'background-color: orange'"/>
  <xsl:param name="label-text">
    <xsl:value-of select="local-name()"/>
  </xsl:param>
  <div style="{$label-style}">
    <xsl:text> </xsl:text>
    <h5 style="font-family: sans-serif;
      font-weight: bold;
      font-style: normal;
      color: midnightblue;
      margin:0em">
      <xsl:value-of select="$label-text"/>
    </h5>
    <xsl:apply-imports/>
    <xsl:if test="not(normalize-space())">
      <h4>No text content!</h4>
    </xsl:if>
  </div>
</xsl:template>

</xsl:stylesheet>