<xsl:stylesheet version="2.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

  <xsl:output method="html" encoding="US-ASCII"/>
  
<xsl:variable name="fileset" select="for $f in //file return document(concat('file:/',/*/root,$f))"/>

<xsl:variable name="fixers"
  select="$fileset/*/front/author[not(normalize-space(bio))]"/>

<xsl:variable name="okays"
  select="$fileset/*/front/author[normalize-space(bio)]"/>

<xsl:template match="/">
  <html>
    <head>
      <title>Bio listing</title>
    </head>
    <body>
      <h2>Documents polled:</h2>
        <ul>
          <xsl:apply-templates select="//file"/>
        </ul>
      <xsl:if test="$fixers">
        <div>
          <h1>No bio present for:</h1>
          <ul>
            <xsl:apply-templates select="$fixers" mode="fixme">
              <xsl:sort select="surname"/>
            </xsl:apply-templates>
          </ul>
        </div>
      </xsl:if>
      <xsl:if test="$okays">
        <div>
          <h1>Biographies collected for:</h1>
          <xsl:apply-templates select="$okays"  mode="fine">
            <xsl:sort select="surname"/>
          </xsl:apply-templates>
        </div>
      </xsl:if>
    </body>
  </html>
</xsl:template>

<xsl:template match="file">
  <li>
    <xsl:apply-templates/>
  </li>
</xsl:template>

<xsl:template match="author" mode="fixme">
  <li>
    <xsl:variable name="uri" select="document-uri(/)"/>
    <xsl:apply-templates select="fname|surname"/>
    <xsl:apply-templates select="address/email"/>
    <xsl:text> [</xsl:text>
    <a href="{$uri}">
      <xsl:value-of select="$uri"/>
    </a>
    <xsl:text>]</xsl:text>
  </li>
</xsl:template>

<xsl:template match="author" mode="fine">
  <div>
    <h3>
      <xsl:apply-templates select="fname|surname"/>
      <xsl:apply-templates select="address/email"/>
    </h3>
    <h4>
    <xsl:variable name="uri" select="document-uri(/)"/>
    <a href="{$uri}">
      <xsl:value-of select="$uri"/>
    </a>
    </h4>
    <xsl:apply-templates select="bio"/>
  </div>
</xsl:template>

<xsl:template match="fname|surname">
  <xsl:if test="preceding-sibling::fname">
    <xsl:text> </xsl:text>
  </xsl:if>
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="para">
  <p>
    <xsl:apply-templates/>
  </p>
</xsl:template>

<xsl:template match="email">
  <xsl:text> [</xsl:text>
    <a href="mailto:{.}">
      <xsl:apply-templates/>
    </a>
  <xsl:text>]</xsl:text>
</xsl:template>


</xsl:stylesheet>