<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0">
  
  <!-- An XSLT 2.0 stylesheet that generates, for an XML document, a
       profile of its tagging.
    
    This could be done in XSLT 1.0, but 2.0 is faster and easier
    
    Creates plain-text output. A fancy version for production use
      might create formatted (HTML or PDF) output
  
    This quickie version:
      lists elements and notes
        number of occurrences
        attributes
          number of occurrences, and
          values represented (with number of occurrences)
      is generic (not tuned for any particular XML input) -->
  
  <xsl:output method="text"/>
  
  <xsl:template name="header">
    <!-- should be customized to the particular document type -->
  </xsl:template>
  
  <xsl:template match="/">
    <xsl:call-template name="header"/>
    <xsl:apply-templates select="/" mode="tag-profile"/>
  </xsl:template>
  
  <xsl:template match="/" mode="tag-profile">
    <xsl:for-each-group select="//*" group-by="name()">
      <xsl:sort select="count(current-group())" order="ascending"/>
      <xsl:variable name="these-elements" select="current-group()"/>
      <xsl:text>&#xA;[</xsl:text>
      <xsl:value-of select="count($these-elements)"/>
      <xsl:text>] </xsl:text>
      <xsl:value-of select="current-grouping-key()"/>
      <xsl:for-each-group select="$these-elements/@*" group-by="name()">
        <xsl:sort select="count(current-group())" order="ascending"/>
        <xsl:text>&#xA;     @</xsl:text>
        <xsl:value-of select="current-grouping-key()"/>
        <xsl:text> (</xsl:text>
        <xsl:value-of select="count(current-group())"/>
        <xsl:text>)</xsl:text>
        <xsl:for-each-group select="current-group()" group-by=".">
          <xsl:sort select="count(current-group())" order="ascending"/>
          <xsl:text>&#xA;       "</xsl:text>
          <xsl:value-of select="current-grouping-key()"/>
          <xsl:text>" (</xsl:text>
          <xsl:value-of select="count(current-group())"/>
          <xsl:text>)</xsl:text>
        </xsl:for-each-group>
      </xsl:for-each-group>
    </xsl:for-each-group>
  </xsl:template>
</xsl:stylesheet>
